#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_IROUND_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_IROUND_HPP_INCLUDED

#include <boost/simd/arithmetic/include/functions/iround.hpp>

#endif
